@@ -32,7 +32,7 @@
 
 from __future__ import division, absolute_import, print_function
 
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 
 import itertools
 
@@ -107,10 +107,11 @@ def bracket_root(f, interval, growth_factor=2, maxiter=100,
         Continuous scalar function.
     interval : sequence of two floats
         Starting interval. Must have non-equal endpoints, but they do not need
-        to be listed in order. During the search, the interval will be expanded
-        in the direction of ``interval[1]``.
+        to be listed in order. During the search, the interval will be shifted
+        and expanded in the direction of ``interval[1]``.
     growth_factor : float, optional
-        How much to grow the length of the interval in each iteration.
+        Factor by which to grow the width of the working interval between
+        iterations. Must be >= 1.
     maxiter : int or None, optional
         Maximum number of iterations. Must be nonnegative. An
         :exc:`IterationLimitReached` exception will be raised if the bracket is
@@ -143,6 +144,9 @@ def bracket_root(f, interval, growth_factor=2, maxiter=100,
     as roots, the one where the absolute value of `f` is lower is chosen as the
     root.
     """
+    if growth_factor < 1:
+        raise ValueError("growth_factor cannot be less than 1")
+
     if ftol is not None and ftol < 0:
         raise ValueError("ftol cannot be negative")
 
@@ -213,7 +217,7 @@ def bracket_root(f, interval, growth_factor=2, maxiter=100,
                                         f_interval=(f_a, f_b),
                                         function_calls=function_calls)
 
-        a, b = b, b + (growth_factor+1)*(b-a)
+        a, b = b, b + growth_factor*(b-a)
         f_a, f_b = f_b, f(b)
         function_calls += 1
 
@@ -277,7 +281,7 @@ def bisect(f, bracket, ftol=1e-12, maxiter=100, f_bracket=(None, None)):
 
     See also
     --------
-    bracket_root : Can find a bracket when one is not known.
+    bracket_root : Search for a bracket.
 
     Notes
     -----
